import gui
import pygame
from quit import *
from game import *
from multiplayerscreen import *
from settingsscreen import *
from gui.dialog import *
from gui.image import *
from gui.checkbox import *
from gui.editfield import *

import select, socket

from players import *


class MultiplayerScreen(Dialog):
        def __init__(self, surface, images, locations):
                self.images = images
                self.locations = locations
		self.player = player
		Dialog.__init__(self, surface)

	def createWidgets(self):
		self.surface.blit(self.images['multiplayerscreen']['background'],(0,0))
	
		self.wm.register(Button(self.images['multiplayerscreen']['hostagame'], self.images['multiplayerscreen']['hostagame'],
			(int(self.locations['multiplayerscreen']['hostagame_x']),
			int(self.locations['multiplayerscreen']['hostagame_y'])),
			callbacks={widget.MOUSEBUTTONUP : self.host }
		))


		self.host = EditField( pygame.font.Font("technical.ttf", 24), text = "localhost", width = int(self.locations['multiplayerscreen']['textfield_size']), position = (
			int(self.locations['multiplayerscreen']['textfield_x']),
			int(self.locations['multiplayerscreen']['textfield_y'])
		),
			cursor = self.images['gui']['cursor'], frameicons = self.images['frame'])
		self.wm.register(self.host)

		self.wm.register(Button(self.images['multiplayerscreen']['joinagame'], self.images['multiplayerscreen']['joinagame'],
                        (int(self.locations['multiplayerscreen']['joinagame_x']),
			int(self.locations['multiplayerscreen']['joinagame_y'])),
                        callbacks={widget.MOUSEBUTTONUP : self.join }
                ))

		self.wm.register(Button(self.images['multiplayerscreen']['return'], self.images['multiplayerscreen']['return'],
			(int(self.locations['endscreen']['return_x']),
			int(self.locations['endscreen']['return_y'])),
			callbacks={widget.MOUSEBUTTONUP : self.return_to_main }
                ))

	def host(self, trigger, event):
                self.surface.blit(self.images['multiplayerscreen']['awaitingconnection'],
			(int(self.locations['multiplayerscreen']['awaitingconnection_x']),
			int(self.locations['multiplayerscreen']['awaitingconnection_y'])))
		pygame.display.flip()
		
		connection = self.connectHost()
		if connection == 'ABORTED':
			self.surface.blit(self.images['startscreen']['background'],(0,0))
			self.wm.paint(1,0)
			return
			
				
		player1 = Human(self.surface, self.images, self.locations, 2)
                player2 = MultiPlayer(self.surface, self.images, self.locations, connection, 1)
						
		#chat = Chat(self.surface, self.images, self.locations)
		chat = None

 		#from game import *

                game = Game(self.surface, self.images, self.locations, player1, player2)
                game.run()

                self.surface.blit(self.images['startscreen']['background'],(0,0))
                self.wm.paint(1,0)

	def join(self, trigger, event):
		self.surface.blit(self.images['multiplayerscreen']['connecting'],
			(int(self.locations['multiplayerscreen']['connecting_x']),
			int(self.locations['multiplayerscreen']['connecting_y'])))
		pygame.display.flip()

	 	connection = self.connectClient(self.host.getText())
                if connection == 'ABORTED':
                        self.surface.blit(self.images['startscreen']['background'],(0,0))
                        self.wm.paint(1,0)
                        return

		player1 = MultiPlayer(self.surface, self.images, self.locations, connection,0)
                player2 = Human(self.surface, self.images, self.locations, 2)

		#chat = Chat(self.surface, self.images, self.locations, self.host.getText())
		chat = None

		#from game import *

                game = Game(self.surface, self.images, self.locations, player1, player2)
		game.run()

                self.surface.blit(self.images['startscreen']['background'],(0,0))
                self.wm.paint(1,0)

        def return_to_main(self, trigger, event):
		self.state = 1
		return widget.DONE
	
	def check_abort(self):
		while not self.abort:
			event = pygame.event.wait()
			if event.type == KEYDOWN and event.key == K_ESCAPE:
				quit()
				return
				
	def connectHost(self):
		s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
		s.bind(('',50000))
		s.listen(1)
			
		result = 0
		while not result:
			(result, q, w) = select.select([s.fileno()],[],[],0.3)
			event = pygame.event.poll()
			if event.type == KEYDOWN and event.key == K_ESCAPE:
				return 'ABORTED'
				
		connection, address = s.accept()
		connection.setblocking(0)

		return connection
	
	def connectClient(self, host):
		connection = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
		trytime = pygame.time.get_ticks()	
		connected = 0
		while not connected:
			try:
				if not connection.connect_ex((host, 50000)):
					connected = 1

			except socket.error:
				connected = 0
				
			if pygame.time.get_ticks() > trytime + 10000:
				return 'ABORTED'
			pygame.time.wait(300)


		connection.setblocking(0)
		return connection
			
			



import rules
from player import *
from random import *

class RandomAI(Player):
	type = 'AI'

	def __init__(self, screen, images, settings, difficulty):
		type = 'AI'

	def doMove(self, board, player):
		while 1:
			move = int(random() * 7)
			if rules.isMoveLegal(board, move):
				return move



###############################################################################################
# $Id: messagebox.py,v 1.1.1.1 2002/02/19 10:16:01 slmm Exp $
###############################################################################################

import pygame
from pygame.locals import *
import scenario
import widget
from dialog         import *
from button         import Button
from image          import Image
from widget_manager import WidgetManager

class Messagebox(Dialog):
    """
    This class is used as a messagebox to display messages to the user while he/she is setting up
    the game. A messagebox is shown centered in the screen and will fade all other contents close to
    black so that the message will be clearly visible. The message is then shown in a smaller box in
    the middle of the screen. No other dialogs or widgets will be receiving events while a
    messagebox is shown. The messagebox can be closed (and the original contents of the window
    restored) by clicking on a button.

    The messagebox attempts to format the passed string using the font 'properties.textfont' and
    present it in a nice manner.

    The messagebox works like a dialog, but the run() method does not need to be called. Instead it
    will be shown immediately when created.
    
    Use this class when you need to show some message temporarily to the user.
    """

    def __init__ (self, text = "", textfont = None, textfont_size = 14):
        "Creates the messagebox and shows it. The user needs to click the button to get close it."

        # load the fonts
        self.font = pygame.font.Font  ( textfont, textfont_size )
        
        # init superclass
        Dialog.__init__ (self, scenario.sdl)

        # load the fade and the box
        self.fade = Image ( properties.messagebox_background, (0, 0), alpha = 160 )
        self.box  = Image ( properties.messagebox_dialog, (112, 200) )
        self.message = Label (self.font, text, (406, 215), color=(255, 255, 0))

        # buttons. We create only the Cancel button so far, the other are created later
        self.button = Button ( properties.path_dialogs + "butt-ok-moff.png",
                               properties.path_dialogs + "butt-ok-mover.png",
                               (406, 500 ), {widget.MOUSEBUTTONUP : self.ok } )

        # register the widgets
        self.wm.register ( self.fade )
        self.wm.register ( self.box )
        self.wm.register ( self.message )
        self.wm.register ( self.button )
        
        # run ourselves!
        self.run ()
        
    
    def ok (self, trigger, event):
        """Callback triggered when the user clicks the 'Ok' button. Simply closes the messagebox."""
        # we're cancelling the dialog
        self.state = ACCEPTED
        return widget.DONE



#  Local Variables:
#  mode: auto-fill
#  fill-column: 100
#  End:



import copy

class Board:
	# Setup an empty board
	def __init__(self):
		self.state = []
        	for x in range(7):
			self.state.append([])
		self.last_move = -1
	
	def move(self, move, player):
		self.state[move].append(player)
		self.last_move = move
	
	def domoves(self, moves):
		for (move, player) in moves:
			self.move(move, player)
			
	def undomove(self, move):
		if len(self.state[move]) > 0:
			del self.state[move][len(self.state[move])-1]



"""
The players of the game
"""

#from treeai   import *
from player   import *
from human    import *
from minmax   import *
from multiplayer import *
from strategic import *
#from agressive import *
from weighted import *
from randomai import *
